/**
 * Created by zhanglei on 2017/5/23.
 */
import React, { Component } from 'react';
import { Modal, message } from 'antd';
import PropTypes from 'prop-types';
import './edit.less';
import ToolBar from './toolBar';
export default class Editor extends Component {
    constructor(props) {
        super(props);
        this.moveToEnd = () => {
            const range = window.getSelection();
            range.selectAllChildren(this.refs['inputText']);
            range.collapseToEnd();
        };
        this.documentClick = (e) => {
            const { isColor, isBackground } = this.state;
            if (isColor || isBackground) {
                let en = e.srcElement || e.target;
                const name = '.color-content';
                while (en) {
                    if (en.className && en.className === name.replace('.', '')) {
                        return;
                    }
                    en = en.parentNode;
                }
                this.setState({ isColor: false, isBackground: false });
            }
        };
        this.onPaste = (e) => {
            let cbd = e.clipboardData;
            let ua = window.navigator.userAgent;
            if (!(e.clipboardData && e.clipboardData.items)) {
                return;
            }
            if (cbd.items && cbd.items.length === 2 && cbd.items[0].kind === "string" && cbd.items[1].kind === "file" &&
                cbd.types && cbd.types.length === 2 && cbd.types[0] === "text/plain" && cbd.types[1] === "Files" &&
                ua.match(/Macintosh/i) && Number(ua.match(/Chrome\/(\d{2})/i)[1]) < 49) {
                return;
            }
            this.onParseOrDrop(cbd, e);
        };
        this.onDrop = (e) => {
            e.preventDefault();
            let cbd = e.dataTransfer;
            let ua = window.navigator.userAgent;
            if (!(e.dataTransfer && e.dataTransfer.items)) {
                return;
            }
            if (cbd.items && cbd.items.length === 2 && cbd.items[0].kind === "string" && cbd.items[1].kind === "file" &&
                cbd.types && cbd.types.length === 2 && cbd.types[0] === "text/plain" && cbd.types[1] === "Files" &&
                ua.match(/Macintosh/i) && Number(ua.match(/Chrome\/(\d{2})/i)[1]) < 49) {
                return;
            }
            this.onParseOrDrop(cbd, e);
        };
        this.onParseOrDrop = (cbd, e) => {
            if (cbd.items && cbd.items.length === 4) {
                document.createElement('table');
                return false;
            }
            const myArray = Object.keys(cbd.items).map(item => {
                return cbd.items[item];
            });
            const arr = myArray.some((u) => {
                if (u.kind === 'file' && u.type !== 'image/jpeg' && u.type !== 'image/png') {
                    message.error('仅支持PNG或者JPG的图片格式上传');
                    return !1;
                }
                return u.kind === 'file' && (u.type === 'image/jpeg' || u.type === 'image/png');
            });
            if (!arr)
                return !1;
            myArray.forEach(item => {
                if (item.kind === 'string') {
                    e.preventDefault();
                    return;
                }
                if (item.kind === "file") {
                    e.preventDefault();
                    const blob = item.getAsFile();
                    if (blob.size === 0)
                        return;
                    this.bind_parse(blob);
                }
            });
        };
        this.bind_parse = (file) => {
            const { editValue } = this.state;
            const reader = new FileReader();
            reader.onload = ((e) => {
                const newImg = `<img class="edit-img" title='点击放大' src="${e.target.result}"/>`;
                const { onChange } = this.props;
                if (onChange) {
                    this.setState({ editValue: editValue + newImg }, () => this.moveToEnd());
                    onChange(editValue + newImg);
                }
            });
            reader.readAsDataURL(file);
        };
        this.textHtml = (e) => {
            e.preventDefault();
            const { isEdit } = this.state;
            let html = null;
            if (isEdit) {
                html = this.refs['inputText'].innerHTML;
                this.refs['inputText2'].value = html;
                this.setState({ isEdit: false, myDisabled: true });
            }
            else {
                html = this.refs['inputText2'].value;
                this.refs['inputText'].innerHTML = html;
                this.setState({ isEdit: true, myDisabled: false });
            }
        };
        this.emitChange = (e) => {
            const { onChange } = this.props;
            const html = e.target.innerHTML;
            if (onChange && html !== this.lastHtml) {
                this.setState({ editValue: html }, () => this.moveToEnd());
                onChange(html);
            }
            this.lastHtml = html;
        };
        this.state = {
            value: null,
            tableData: [],
            linkModel: false,
            visible: false,
            isColor: false,
            editValue: '',
            myDisabled: false,
            isEdit: true,
            isFace: false,
            isBackground: false,
            linkValue: null,
            isSent: true,
        };
    }
    ;
    componentDidMount() {
        document.addEventListener('click', this.documentClick);
    }
    ;
    componentWillReceiveProps(nextProps) {
        if ('value' in nextProps && this.props.value !== nextProps.value) {
            this.setState({ editValue: nextProps.value }, () => {
                this.moveToEnd();
            });
        }
    }
    componentWillUnmount() {
        document.removeEventListener('click', this.documentClick);
    }
    shouldComponentUpdate(nextProps, nextState) {
        return nextProps.value !== this.props.value ||
            this.state.editValue !== nextState.editValue ||
            this.state.visible !== nextState.visible ||
            this.state.myDisabled !== nextState.myDisabled;
    }
    render() {
        const { isEdit, visible, myDisabled } = this.state;
        const { disabled, editColor } = this.props;
        const isDisabled = !('disabled' in this.props) || !disabled;
        return (React.createElement("div", { className: "editor-full" },
            isDisabled &&
            React.createElement(ToolBar, { id: this.props.id, myDisabled: myDisabled, bind_parse: (this.bind_parse), textHtml: (this.textHtml) }),
            React.createElement("div", { className: "inputText", style: { borderColor: editColor } },
                React.createElement("div", { className: "input-content-edit", onPaste: this.onPaste, onDrop: this.onDrop, onCompositionEnd: this.emitChange, onInput: this.emitChange, contentEditable: isDisabled, onBlur: this.emitChange, dangerouslySetInnerHTML: { __html: this.state.editValue || this.props.value }, onClick: e => {
                    if (e.target.title === '点击放大') {
                        this.setState({ url: e.target.src, visible: true });
                    }
                }, ref: "inputText", style: {
                    display: isEdit ? 'block' : 'none',
                    height: isDisabled ? '200px' : 'auto'
                } }),
                React.createElement("textarea", { style: { display: isEdit ? 'none' : 'block' }, ref: "inputText2", id: "editor-con" })),
            React.createElement(Modal, { className: "chat-model", style: { width: '70%' }, visible: visible, footer: null, onCancel: () => this.setState({ visible: false }) },
                React.createElement("img", { src: this.state.url, alt: "img" }))));
    }
}
Editor.propTypes = {
    className: PropTypes.string,
    value: PropTypes.string,
    editColor: PropTypes.string,
};
